@@ -1,4 +1,4 @@
-/*	$OpenBSD: inetd.c,v 1.123 2005/04/02 18:10:52 otto Exp $	*/
+/*	$OpenBSD: inetd.c,v 1.125 2008/01/05 09:53:42 jmc Exp $	*/
 
 /*
  * Copyright (c) 1983,1991 The Regents of the University of California.
@@ -37,7 +37,7 @@ char copyright[] =
 
 #ifndef lint
 /*static const char sccsid[] = "from: @(#)inetd.c	5.30 (Berkeley) 6/3/91";*/
-static const char rcsid[] = "$OpenBSD: inetd.c,v 1.123 2005/04/02 18:10:52 otto Exp $";
+static const char rcsid[] = "$OpenBSD: inetd.c,v 1.125 2008/01/05 09:53:42 jmc Exp $";
 #endif /* not lint */
 
 /*
@@ -358,7 +358,8 @@ main(int argc, char *argv[])
 		}
 		case '?':
 		default:
-			fprintf(stderr, "usage: %s [-R rate] [-d] [conf]\n",
+			fprintf(stderr,
+			    "usage: %s [-d] [-R rate] [configuration file]\n",
 			    progname);
 			exit(1);
 		}
@@ -375,6 +376,11 @@ main(int argc, char *argv[])
 		    progname);
 		exit(1);
 	}
+	if (argc > 1) {
+		fprintf(stderr, "%s: more than one argument specified\n",
+		    progname);
+		exit(1);
+	}
 
 	umask(022);
 	if (debug == 0) {
@@ -1494,13 +1500,9 @@ again:
 char *
 nextline(FILE *fd)
 {
-	char *cp;
-
 	if (fgets(line, sizeof (line), fd) == NULL)
 		return (NULL);
-	cp = strchr(line, '\n');
-	if (cp)
-		*cp = '\0';
+	line[strcspn(line, "\n")] = '\0';
 	return (line);
 }
 
